@@ -26,11 +26,12 @@
 #ifndef __LIBXFCE4UTIL_PRIVATE_H__
 #define __LIBXFCE4UTIL_PRIVATE_H__
 
-#include <libxfce4util/libxfce4util.h>
+#include "libxfce4util.h"
 
 G_BEGIN_DECLS
 
-G_GNUC_INTERNAL void _xfce_i18n_init (void);
+G_GNUC_INTERNAL void
+_xfce_i18n_init (void);
 
 G_END_DECLS
 
