@@ -29,7 +29,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #ifdef HAVE_SYS_TYPES_H
@@ -46,8 +46,8 @@
 #include <unistd.h>
 #endif
 
-#include <libxfce4util/libxfce4util-private.h>
-#include <libxfce4util/libxfce4util-alias.h>
+#include "libxfce4util-private.h"
+#include "libxfce4util-visibility.h"
 
 
 
@@ -71,8 +71,8 @@
  **/
 gboolean
 xfce_mkdirhier (const gchar *whole_path,
-                gulong       mode,
-                GError     **error)
+                gulong mode,
+                GError **error)
 {
   /* Stolen from FreeBSD's mkdir(1) with modifications to make it
    * work properly with NFS on Solaris */
@@ -93,7 +93,7 @@ xfce_mkdirhier (const gchar *whole_path,
   if (p[0] == G_DIR_SEPARATOR) /* Skip leading '/'. */
     ++p;
 
-  for (first = 1, last = 0; !last ; ++p)
+  for (first = 1, last = 0; !last; ++p)
     {
       if (p[0] == '\0')
         last = 1;
@@ -118,14 +118,14 @@ xfce_mkdirhier (const gchar *whole_path,
            * We change the user's umask and then restore it,
            * instead of doing chmod's.
            */
-          oumask = umask(0);
+          oumask = umask (0);
           numask = oumask & ~(S_IWUSR | S_IXUSR);
-          umask(numask);
+          umask (numask);
           first = 0;
         }
 
       if (last)
-        umask(oumask);
+        umask (oumask);
 
       if (mkdir (path, last ? mode : S_IRWXU | S_IRWXG | S_IRWXO) < 0)
         {
@@ -183,23 +183,25 @@ xfce_mkdirhier (const gchar *whole_path,
  *
  * Since: 4.17.1
  **/
-gchar*
+gchar *
 xfce_create_shared_thumbnail_path (const gchar *uri,
                                    const gchar *size)
 {
-  GChecksum   *checksum;
-  gchar       *dir_uri;
-  gchar       *dir_path;
-  gchar       *name;
-  gchar       *filename;
-  gchar       *thumbnail_path;
+  GChecksum *checksum;
+  gchar *dir_uri;
+  gchar *dir_path;
+  gchar *basename;
+  gchar *relname;
+  gchar *filename;
+  gchar *thumbnail_path;
 
-  name = g_path_get_basename (uri);
+  basename = g_path_get_basename (uri);
+  relname = g_build_filename (".", basename, NULL);
   dir_uri = g_path_get_dirname (uri);
   dir_path = g_filename_from_uri (dir_uri, NULL, NULL); /* drop file:// */
 
   checksum = g_checksum_new (G_CHECKSUM_MD5);
-  g_checksum_update (checksum, (const guchar *) name, strlen (name));
+  g_checksum_update (checksum, (const guchar *) relname, strlen (relname));
   filename = g_strconcat (g_checksum_get_string (checksum), ".png", NULL);
 
   if (dir_path != NULL)
@@ -208,7 +210,8 @@ xfce_create_shared_thumbnail_path (const gchar *uri,
     thumbnail_path = NULL;
 
   /* free memory */
-  g_free (name);
+  g_free (basename);
+  g_free (relname);
   g_free (filename);
   g_free (dir_uri);
   g_free (dir_path);
@@ -219,4 +222,4 @@ xfce_create_shared_thumbnail_path (const gchar *uri,
 
 
 #define __XFCE_FILEUTILS_C__
-#include <libxfce4util/libxfce4util-aliasdef.c>
+#include "libxfce4util-visibility.c"
